@@ -13,7 +13,6 @@ from ..exceptions import CommandVacuumError, RoborockException, VacuumError
 from ..protocol import Utils
 from ..protocols.v1_protocol import SecurityData, create_mqtt_payload_encoder
 from ..roborock_message import (
-    RoborockMessage,
     RoborockMessageProtocol,
 )
 from ..roborock_typing import RoborockCommand
@@ -41,10 +40,19 @@ class RoborockMqttClientV1(RoborockMqttClient, RoborockClientV1):
             SecurityData(endpoint=self._endpoint, nonce=self._nonce),
         )
 
-    async def send_message(self, roborock_message: RoborockMessage):
+    async def _send_command(
+        self,
+        method: RoborockCommand | str,
+        params: list | dict | int | None = None,
+    ):
+        if method in CUSTOM_COMMANDS:
+            # When we have more custom commands do something more complicated here
+            return await self._get_calibration_points()
+
+        roborock_message = self._payload_encoder(method, params)
+        self._logger.debug("Building message id %s for method %s", roborock_message.get_request_id, method)
+
         await self.validate_connection()
-        method = roborock_message.get_method()
-        params = roborock_message.get_params()
         request_id = roborock_message.get_request_id()
         if request_id is None:
             raise RoborockException(f"Failed build message {roborock_message}")
@@ -60,12 +68,12 @@ class RoborockMqttClientV1(RoborockMqttClient, RoborockClientV1):
             response = await async_response
         except VacuumError as err:
             self._diagnostic_data[diagnostic_key] = {
-                "params": roborock_message.get_params(),
+                "params": params,
                 "error": err,
             }
             raise CommandVacuumError(method, err) from err
         self._diagnostic_data[diagnostic_key] = {
-            "params": roborock_message.get_params(),
+            "params": params,
             "response": response,
         }
         if response_protocol == RoborockMessageProtocol.MAP_RESPONSE:
@@ -74,19 +82,6 @@ class RoborockMqttClientV1(RoborockMqttClient, RoborockClientV1):
             self._logger.debug(f"id={request_id} Response from {method}: {response}")
         return response
 
-    async def _send_command(
-        self,
-        method: RoborockCommand | str,
-        params: list | dict | int | None = None,
-    ):
-        if method in CUSTOM_COMMANDS:
-            # When we have more custom commands do something more complicated here
-            return await self._get_calibration_points()
-
-        roborock_message = self._payload_encoder(method, params)
-        self._logger.debug("Building message id %s for method %s", roborock_message.get_request_id, method)
-        return await self.send_message(roborock_message)
-
     async def _get_calibration_points(self):
         map: bytes = await self.send_command(RoborockCommand.GET_MAP_V1)
         parser = RoborockMapDataParser(ColorsPalette(), Sizes(), [], ImageConfig(), [])
