@@ -11,12 +11,13 @@ from unittest.mock import AsyncMock, Mock
 import pytest
 
 from roborock.containers import NetworkInfo, RoborockStateCode, S5MaxStatus, UserData
+from roborock.devices.cache import CacheData, InMemoryCache
 from roborock.devices.local_channel import LocalChannel, LocalSession
 from roborock.devices.mqtt_channel import MqttChannel
 from roborock.devices.v1_channel import V1Channel
 from roborock.exceptions import RoborockException
 from roborock.protocol import create_local_decoder, create_local_encoder, create_mqtt_decoder, create_mqtt_encoder
-from roborock.protocols.v1_protocol import SecurityData, encode_local_payload
+from roborock.protocols.v1_protocol import SecurityData
 from roborock.roborock_message import RoborockMessage, RoborockMessageProtocol
 from roborock.roborock_typing import RoborockCommand
 
@@ -59,7 +60,7 @@ def setup_mock_mqtt_channel() -> Mock:
     """Mock MQTT channel for testing."""
     mock_mqtt = AsyncMock(spec=MqttChannel)
     mock_mqtt.subscribe = AsyncMock()
-    mock_mqtt.send_command = AsyncMock()
+    mock_mqtt.send_message = AsyncMock()
     return mock_mqtt
 
 
@@ -69,10 +70,10 @@ def setup_mqtt_responses(mock_mqtt_channel: Mock) -> list[RoborockMessage]:
 
     responses: list[RoborockMessage] = [TEST_NETWORK_INFO_RESPONSE]
 
-    def send_command(*args) -> RoborockMessage:
+    def send_message(*args) -> RoborockMessage:
         return responses.pop(0)
 
-    mock_mqtt_channel.send_command.side_effect = send_command
+    mock_mqtt_channel.send_message.side_effect = send_message
     return responses
 
 
@@ -82,7 +83,7 @@ def setup_mock_local_channel() -> Mock:
     mock_local = AsyncMock(spec=LocalChannel)
     mock_local.connect = AsyncMock()
     mock_local.subscribe = AsyncMock()
-    mock_local.send_command = AsyncMock()
+    mock_local.send_message = AsyncMock()
     return mock_local
 
 
@@ -105,6 +106,7 @@ def setup_v1_channel(
         security_data=TEST_SECURITY_DATA,
         mqtt_channel=mock_mqtt_channel,
         local_session=mock_local_session,
+        cache=InMemoryCache(),
     )
 
 
@@ -125,7 +127,7 @@ async def test_v1_channel_subscribe_mqtt_only_success(
     # Setup: MQTT succeeds, local fails
     mqtt_unsub = Mock()
     mock_mqtt_channel.subscribe.return_value = mqtt_unsub
-    mock_mqtt_channel.send_command.return_value = TEST_NETWORK_INFO_RESPONSE
+    mock_mqtt_channel.send_message.return_value = TEST_NETWORK_INFO_RESPONSE
     mock_local_channel.connect.side_effect = RoborockException("Connection failed")
 
     callback = Mock()
@@ -211,7 +213,7 @@ async def test_v1_channel_local_connection_warning_logged(
 # V1Channel command sending with fallback logic tests
 
 
-async def test_v1_channel_send_decoded_command_local_preferred(
+async def test_v1_channel_send_command_local_preferred(
     v1_channel: V1Channel,
     mock_mqtt_channel: Mock,
     mock_local_channel: Mock,
@@ -219,22 +221,22 @@ async def test_v1_channel_send_decoded_command_local_preferred(
     """Test command sending prefers local connection when available."""
     # Establish connections
     await v1_channel.subscribe(Mock())
-    mock_mqtt_channel.send_command.reset_mock(return_value=False)
+    mock_mqtt_channel.send_message.reset_mock(return_value=False)
 
     # Send command
-    mock_local_channel.send_command.return_value = TEST_RESPONSE
-    result = await v1_channel.send_decoded_command(
+    mock_local_channel.send_message.return_value = TEST_RESPONSE
+    result = await v1_channel.rpc_channel.send_command(
         RoborockCommand.CHANGE_SOUND_VOLUME,
         response_type=S5MaxStatus,
     )
 
     # Verify local was used, not MQTT
-    mock_local_channel.send_command.assert_called_once()
-    mock_mqtt_channel.send_command.assert_not_called()
+    mock_local_channel.send_message.assert_called_once()
+    mock_mqtt_channel.send_message.assert_not_called()
     assert result.state == RoborockStateCode.cleaning
 
 
-async def test_v1_channel_send_decoded_command_local_fails(
+async def test_v1_channel_send_command_local_fails(
     v1_channel: V1Channel,
     mock_mqtt_channel: Mock,
     mock_local_channel: Mock,
@@ -244,22 +246,22 @@ async def test_v1_channel_send_decoded_command_local_fails(
 
     # Establish connections
     await v1_channel.subscribe(Mock())
-    mock_mqtt_channel.send_command.reset_mock(return_value=False)
+    mock_mqtt_channel.send_message.reset_mock(return_value=False)
 
     # Local command fails
-    mock_local_channel.send_command.side_effect = RoborockException("Local failed")
+    mock_local_channel.send_message.side_effect = RoborockException("Local failed")
 
     # Send command
     mqtt_responses.append(TEST_RESPONSE)
     with pytest.raises(RoborockException, match="Local failed"):
-        await v1_channel.send_decoded_command(
+        await v1_channel.rpc_channel.send_command(
             RoborockCommand.CHANGE_SOUND_VOLUME,
             response_type=S5MaxStatus,
         )
 
     # Verify local was attempted but not mqtt
-    mock_local_channel.send_command.assert_called_once()
-    mock_mqtt_channel.send_command.assert_not_called()
+    mock_local_channel.send_message.assert_called_once()
+    mock_mqtt_channel.send_message.assert_not_called()
 
 
 async def test_v1_channel_send_decoded_command_mqtt_only(
@@ -274,19 +276,19 @@ async def test_v1_channel_send_decoded_command_mqtt_only(
     mock_local_channel.connect.side_effect = RoborockException("No local")
 
     await v1_channel.subscribe(Mock())
-    mock_mqtt_channel.send_command.assert_called_once()  # network info
-    mock_mqtt_channel.send_command.reset_mock(return_value=False)
+    mock_mqtt_channel.send_message.assert_called_once()  # network info
+    mock_mqtt_channel.send_message.reset_mock(return_value=False)
 
     # Send command
     mqtt_responses.append(TEST_RESPONSE)
-    result = await v1_channel.send_decoded_command(
+    result = await v1_channel.rpc_channel.send_command(
         RoborockCommand.CHANGE_SOUND_VOLUME,
         response_type=S5MaxStatus,
     )
 
     # Verify only MQTT was used
-    mock_local_channel.send_command.assert_not_called()
-    mock_mqtt_channel.send_command.assert_called_once()
+    mock_local_channel.send_message.assert_not_called()
+    mock_mqtt_channel.send_message.assert_called_once()
     assert result.state == RoborockStateCode.cleaning
 
 
@@ -300,17 +302,17 @@ async def test_v1_channel_send_decoded_command_with_params(
     await v1_channel.subscribe(Mock())
 
     # Send command with params
-    mock_local_channel.send_command.return_value = TEST_RESPONSE
+    mock_local_channel.send_message.return_value = TEST_RESPONSE
     test_params = {"volume": 80}
-    await v1_channel.send_decoded_command(
+    await v1_channel.rpc_channel.send_command(
         RoborockCommand.CHANGE_SOUND_VOLUME,
         response_type=S5MaxStatus,
         params=test_params,
     )
 
     # Verify command was sent with correct params
-    mock_local_channel.send_command.assert_called_once()
-    call_args = mock_local_channel.send_command.call_args
+    mock_local_channel.send_message.assert_called_once()
+    call_args = mock_local_channel.send_message.call_args
     sent_message = call_args[0][0]
     assert sent_message
     assert isinstance(sent_message, RoborockMessage)
@@ -388,7 +390,7 @@ async def test_v1_channel_networking_info_retrieved_during_connection(
     """Test that networking information is retrieved during local connection setup."""
     # Setup: MQTT returns network info when requested
     mock_mqtt_channel.subscribe.return_value = Mock()
-    mock_mqtt_channel.send_command.return_value = RoborockMessage(
+    mock_mqtt_channel.send_message.return_value = RoborockMessage(
         protocol=RoborockMessageProtocol.RPC_RESPONSE,
         payload=json.dumps({"dps": {"102": json.dumps({"id": 12345, "result": mock_data.NETWORK_INFO})}}).encode(),
     )
@@ -402,12 +404,58 @@ async def test_v1_channel_networking_info_retrieved_during_connection(
     assert v1_channel.is_local_connected
 
     # Verify network info was requested via MQTT
-    mock_mqtt_channel.send_command.assert_called_once()
+    mock_mqtt_channel.send_message.assert_called_once()
 
     # Verify local session was created with the correct IP
     mock_local_session.assert_called_once_with(mock_data.NETWORK_INFO["ip"])
 
 
+async def test_v1_channel_networking_info_cached_during_connection(
+    mock_mqtt_channel: Mock,
+    mock_local_channel: Mock,
+    mock_local_session: Mock,
+) -> None:
+    """Test that networking information is cached and reused on subsequent connections."""
+
+    # Create a cache with pre-populated network info
+    cache_data = CacheData()
+    cache_data.network_info[TEST_DEVICE_UID] = TEST_NETWORKING_INFO
+
+    mock_cache = AsyncMock()
+    mock_cache.get.return_value = cache_data
+    mock_cache.set = AsyncMock()
+
+    # Setup: MQTT and local connections succeed
+    mock_mqtt_channel.subscribe.return_value = Mock()
+    mock_local_channel.subscribe.return_value = Mock()
+
+    # Create V1Channel with the mock cache
+    v1_channel = V1Channel(
+        device_uid=TEST_DEVICE_UID,
+        security_data=TEST_SECURITY_DATA,
+        mqtt_channel=mock_mqtt_channel,
+        local_session=mock_local_session,
+        cache=mock_cache,
+    )
+
+    # Subscribe - should use cached network info
+    await v1_channel.subscribe(Mock())
+
+    # Verify both connections are established
+    assert v1_channel.is_mqtt_connected
+    assert v1_channel.is_local_connected
+
+    # Verify network info was NOT requested via MQTT (cache hit)
+    mock_mqtt_channel.send_message.assert_not_called()
+
+    # Verify local session was created with the correct IP from cache
+    mock_local_session.assert_called_once_with(mock_data.NETWORK_INFO["ip"])
+
+    # Verify cache was accessed but not updated (cache hit)
+    mock_cache.get.assert_called_once()
+    mock_cache.set.assert_not_called()
+
+
 # V1Channel edge cases tests
 
 
@@ -416,7 +464,7 @@ async def test_v1_channel_local_connect_network_info_failure(
     mock_mqtt_channel: Mock,
 ) -> None:
     """Test local connection when network info retrieval fails."""
-    mock_mqtt_channel.send_command.side_effect = RoborockException("Network info failed")
+    mock_mqtt_channel.send_message.side_effect = RoborockException("Network info failed")
 
     with pytest.raises(RoborockException):
         await v1_channel._local_connect()
@@ -429,7 +477,7 @@ async def test_v1_channel_local_connect_connection_failure(
 ) -> None:
     """Test local connection when connection itself fails."""
     # Network info succeeds but connection fails
-    mock_mqtt_channel.send_command.return_value = RoborockMessage(
+    mock_mqtt_channel.send_message.return_value = RoborockMessage(
         protocol=RoborockMessageProtocol.RPC_RESPONSE,
         payload=json.dumps({"dps": {"102": json.dumps({"id": 12345, "result": mock_data.NETWORK_INFO})}}).encode(),
     )
@@ -439,13 +487,27 @@ async def test_v1_channel_local_connect_connection_failure(
         await v1_channel._local_connect()
 
 
-async def test_v1_channel_command_encoding_validation(v1_channel: V1Channel) -> None:
+async def test_v1_channel_command_encoding_validation(
+    v1_channel: V1Channel,
+    mqtt_responses: list[RoborockMessage],
+    mock_mqtt_channel: Mock,
+    mock_local_channel: Mock,
+) -> None:
     """Test that command encoding works for different protocols."""
-    # Test MQTT encoding
-    mqtt_message = v1_channel._mqtt_payload_encoder(RoborockCommand.CHANGE_SOUND_VOLUME, {"volume": 50})
+    await v1_channel.subscribe(Mock())
+    mock_mqtt_channel.send_message.reset_mock(return_value=False)
 
-    # Test local encoding
-    local_message = encode_local_payload(RoborockCommand.CHANGE_SOUND_VOLUME, {"volume": 50})
+    # Send mqtt command and capture the request
+    mqtt_responses.append(TEST_RESPONSE)
+    await v1_channel.mqtt_rpc_channel.send_command(RoborockCommand.CHANGE_SOUND_VOLUME, params={"volume": 50})
+    mock_mqtt_channel.send_message.assert_called_once()
+    mqtt_message = mock_mqtt_channel.send_message.call_args[0][0]
+
+    # Send local command and capture the request
+    mock_local_channel.send_message.return_value = TEST_RESPONSE
+    await v1_channel.rpc_channel.send_command(RoborockCommand.CHANGE_SOUND_VOLUME, params={"volume": 50})
+    mock_local_channel.send_message.assert_called_once()
+    local_message = mock_local_channel.send_message.call_args[0][0]
 
     # Verify both are RoborockMessage instances
     assert isinstance(mqtt_message, RoborockMessage)
@@ -491,7 +553,7 @@ async def test_v1_channel_full_subscribe_and_command_flow(
     local_unsub = Mock()
     mock_mqtt_channel.subscribe.return_value = mqtt_unsub
     mock_local_channel.subscribe.return_value = local_unsub
-    mock_local_channel.send_command.return_value = TEST_RESPONSE
+    mock_local_channel.send_message.return_value = TEST_RESPONSE
 
     # Create V1Channel and subscribe
     v1_channel = V1Channel(
@@ -499,26 +561,27 @@ async def test_v1_channel_full_subscribe_and_command_flow(
         security_data=TEST_SECURITY_DATA,
         mqtt_channel=mock_mqtt_channel,
         local_session=mock_local_session,
+        cache=InMemoryCache(),
     )
 
     # Mock network info for local connection
     callback = Mock()
     unsub = await v1_channel.subscribe(callback)
-    mock_mqtt_channel.send_command.reset_mock(return_value=False)
+    mock_mqtt_channel.send_message.reset_mock(return_value=False)
 
     # Verify both connections established
     assert v1_channel.is_mqtt_connected
     assert v1_channel.is_local_connected
 
     # Send a command (should use local)
-    result = await v1_channel.send_decoded_command(
+    result = await v1_channel.rpc_channel.send_command(
         RoborockCommand.GET_STATUS,
         response_type=S5MaxStatus,
     )
 
     # Verify command was sent via local connection
-    mock_local_channel.send_command.assert_called_once()
-    mock_mqtt_channel.send_command.assert_not_called()
+    mock_local_channel.send_message.assert_called_once()
+    mock_mqtt_channel.send_message.assert_not_called()
     assert result.state == RoborockStateCode.cleaning
 
     # Test message callback
